@@ -379,7 +379,10 @@ class GSPeerConnectionBroadcasterPiSocketv2:
 
 
             # loop.run_until_complete( pc.setLocalDescription(awaitpc.createOffer()))
-            asyncio.run(create_and_set_local_description(pc))
+            # asyncio.run(create_and_set_local_description(pc))
+            async with pc:
+                await create_and_set_local_description(pc)
+
 
 
             self.sio.emit("watcher", {"target": description,
